#pragma once

extern const struct log_info log_info;

/* Debug Areas of the code */
enum {
	DMAIN,
	DTRXCTRL,
	DDEV,
	DLMS,
};
